Learn R Programming

pacu (version 0.1.74)

pa_check_yield: Check the yield data before processing with the pa_yield function

Description

This function will check for red flags so the user can know of potential problems before using the pa_yield functions

Usage

pa_check_yield(input, algorithm = c("all", "simple", "ritas"))

Value

object of class check.yield

Arguments

input

an sf object containing the input data from a yield monitor

algorithm

for which algorithm should the function check the data. Different algorithms require different information to be present in the input data set.

Author

Caio dos Santos and Fernando Miguez

Details

This function will check the input yield data for any potential problems before the user runs the `pa_yield()` function. Ideally, this function warn the user of potential problems.

Examples

Run this code
# \donttest{
extd.dir <- system.file("extdata", package = "pacu")
raw.yield <- sf::read_sf(file.path(extd.dir, '2012-basswood.shp'),
                         quiet = TRUE)
chk <- pa_check_yield(raw.yield)
chk
# }

Run the code above in your browser using DataLab