Learn R Programming

pacu (version 0.1.74)

pa_download_dataspace: Download satellite products from the Copernicus Data Space Ecosystem

Description

Download satellite products from the Copernicus Data Space Ecosystem to find satellite products

Usage

pa_download_dataspace(x, dir.path = NULL, aoi = NULL, verbose = TRUE)

Value

a list of objects that could not be downloaded

Arguments

x

object of class ‘dslist’

dir.path

directory path to which the files will be saved

aoi

NULL or an sf object. If an area of interest (aoi) is provided, the downloaded zip files will be cropped to the aoi. This was designed to save storage space

verbose

whether to display information on the progress of operations

Author

Caio dos Santos and Fernando Miguez

Details

`pa_download_dataspace()` uses the object from `pa_browse_dataspace()` to download the data from Copernicus Data Space. The aoi argument is optional but was designed to save storage space.

Examples

Run this code
if (FALSE) {
extd.dir <- system.file("extdata", package = "pacu")
area.of.interest <- sf::st_read(file.path(extd.dir, 'cobs_a_aoi.shp'), quiet = TRUE)
available.images <- pa_browse_dataspace(aoi = area.of.interest,
                                        max.cloud.cover = 10,
                                        start.date = '2023-01-01',
                                        end.date = '2023-12-31')
dwonloaded.images <- pa_download_dataspace(x = available.images)

}

Run the code above in your browser using DataLab