pa_make_vehicle_polygons: Make vehicular polygons for yield monitor
observations
Description
Make vehicular polygons for yield monitor
observations
Usage
pa_make_vehicle_polygons(
points,
swath,
distance,
angle = NULL,
cores = 1L,
verbose = FALSE
)
Arguments
- points
a vector of points
- swath
a vector containing the swath of the vehicle
in meters
- distance
a vector containing the distance traveled
by the vehicle in meters
- angle
a vector containing the angle of the
vehicle's trajectory. If not supplied, the function
will attempt to estimate the trajectory angle using the
geographical information contained in the georeferenced
points/
- cores
the number of cores used in the operation
- verbose
whether to print operation details
Author
Caio dos Santos and Fernando Miguez
Details
This function will create vehicular polygons
based on the distance between points, angle of the
vehicle's trajectory, and swath.
Examples
Run this code# \donttest{
## for examples, see vignette pacu
# }
Run the code above in your browser using DataLab