as a side effect it modifies the ‘pacu.options’ environment.
Arguments
suppress.warnings
whether to suppress warning messages
suppress.messages
whether to suppress messages
apportion.size.multiplier
a multiplier used to determine the size of the
apportioning polygons in the RITAS algorithm. A value of sqrt(2) will make polygons
approximately the same size as the harvest polygons. Smaller values increase the resolution
but also increase the computation time substantially.
minimum.coverage.fraction
The minimum area of an apportioning polygon that needs to be covered
to conduct the apportioning operation.